#!/bin/sh

# 1 - Root kontrolü
if [ "$EUID" -ne 0 ]; then
    echo "etap+pardus!" | sudo -S "$0" "$@"
    exit
fi

echo "[+] Yetki kontrolü tamamlandı. Root olarak çalışıyor."

# Eğer --fresh parametresiyle çalıştırıldıysa sadece sudoers güncelle
if [ "$1" = "--fresh" ]; then

    SUDOERS_PATH="/etc/sudoers"

    cat <<EOL > "$SUDOERS_PATH"
#
# This file MUST be edited with the 'visudo' command as root.
#

Defaults    env_reset
Defaults    mail_badpass
Defaults    secure_path="/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"

root    ALL=(ALL:ALL) ALL
%sudo   ALL=(ALL:ALL) ALL
ALL     ALL=NOPASSWD: /usr/local/bin/i-kilit
EOL

    chmod 440 "$SUDOERS_PATH"
    chown root:root "$SUDOERS_PATH"
    echo "[+] /etc/sudoers dosyası güncellendi."

    exit 0
fi

# 2 - Sudoers dosyasını güncelle
SUDOERS_PATH="/etc/sudoers"

cat <<EOL > "$SUDOERS_PATH"
#
# This file MUST be edited with the 'visudo' command as root.
#

Defaults    env_reset
Defaults    mail_badpass
Defaults    secure_path="/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"

root    ALL=(ALL:ALL) ALL
%sudo   ALL=(ALL:ALL) ALL
ALL     ALL=NOPASSWD: /usr/local/bin/i-kilit
EOL

chmod 440 "$SUDOERS_PATH"
chown root:root "$SUDOERS_PATH"
echo "[+] /etc/sudoers dosyası güncellendi."

# 3 - Autostart desktop entry
AUTOSTART_FILE="/etc/xdg/autostart/i-kilit-autostart.desktop"
if [ ! -f "$AUTOSTART_FILE" ]; then
    cat <<EOF > "$AUTOSTART_FILE"
[Desktop Entry]
Type=Application
Name=i-kilit Autostart
Comment=Automatically start i-kilit with root privileges via setuid
Exec=/usr/local/bin/i-kilit -entry
X-GNOME-Autostart-enabled=true
NoDisplay=false
EOF
    chmod 755 "$AUTOSTART_FILE"
    echo "[+] Autostart dosyası oluşturuldu: $AUTOSTART_FILE"
else
    echo "[*] Autostart dosyası zaten mevcut."
fi

# 4 - Application Menu Entry
DESKTOP_FILE="/usr/share/applications/i-kilit.desktop"
if [ ! -f "$DESKTOP_FILE" ]; then
    cat <<EOF > "$DESKTOP_FILE"
[Desktop Entry]
Name=i-Kilit
Type=Application
Comment=Güvenlik Kilidi Uygulaması
Exec=env FYNE_SCALE=1.1 /usr/local/bin/i-kilit
Icon=/usr/local/share/pixmaps/i-kilit.png
Terminal=false
Categories=System;
EOF
    chmod 755 "$DESKTOP_FILE"
    echo "[+] Masaüstü kısayolu oluşturuldu: $DESKTOP_FILE"
else
    echo "[*] Masaüstü kısayolu zaten mevcut."
fi

# 5 - SetUID ve chown kontrolü
TARGET_BIN="/usr/local/bin/i-kilit"
if [ -f "$TARGET_BIN" ]; then
    OWNER=$(stat -c "%U:%G" "$TARGET_BIN")
    PERMS=$(stat -c "%a" "$TARGET_BIN")

    if [ "$OWNER" != "root:root" ]; then
        chown root:root "$TARGET_BIN"
        echo "[+] $TARGET_BIN sahibi root:root olarak ayarlandı."
    else
        echo "[*] $TARGET_BIN sahibi zaten root:root."
    fi

    if [ "$PERMS" != "4755" ]; then
        chmod 4755 "$TARGET_BIN"
        echo "[+] $TARGET_BIN izni 4755 (setuid) olarak ayarlandı."
    else
        echo "[*] $TARGET_BIN izni zaten 4755."
    fi
else
    echo "[!] $TARGET_BIN bulunamadı!"
fi

# 6 - Konfigürasyon Dosyalarının /root'a Taşınması
mv /home/i-kilit/config.enc /root
mv /var/lib/i-kilit/config.enc /root
mv /home/config.enc /root